@@ -76,20 +76,11 @@ class InteractiveMode:
         )
     
     def show_welcome(self):
-        """Показать приветствие"""
-        self.console.print(Panel.fit(
-            "🤖 [bold blue]Добро пожаловать в DurusAI Interactive Mode![/bold blue]\n\n"
-            f"📋 Текущая модель: [cyan]{self.current_model}[/cyan]\n"
-            f"🔧 API: [dim]{self.config.get_api_endpoint()}[/dim]\n\n"
-            "[yellow]Команды:[/yellow]\n"
-            "• [green]/help[/green] - показать справку\n"
-            "• [green]/model <name>[/green] - сменить модель\n"
-            "• [green]/clear[/green] - очистить историю\n"
-            "• [green]/quit[/green] или [green]Ctrl+D[/green] - выйти\n\n"
-            "[dim]Просто начните печатать ваш вопрос...[/dim]",
-            title="🚀 Interactive Mode",
-            border_style="blue"
-        ))
+        """Показать приветствие в стиле Claude"""
+        # Минималистичное приветствие без больших рамок
+        self.console.print(f"🤖 [bold blue]DurusAI[/bold blue]")
+        self.console.print(f"[dim]Модель: {self.current_model} | Команды: /help, /model, /quit[/dim]")
+        self.console.print()
     
     def show_help(self):
         """Показать справку"""
@@ -277,11 +268,11 @@ class InteractiveMode:
             model_used = result.get("model_used", self.current_model)
             tokens_used = result.get("tokens_used", {}).get("total", 0)
             
-            # Рендерим Markdown если возможно
+            # Рендерим ответ в минималистичном стиле Claude
             try:
-                self.console.print(Panel(Markdown(response), title="🤖 AI Response", border_style="green"))
+                self.console.print(Markdown(response))
             except:
-                self.console.print(Panel(response, title="🤖 AI Response", border_style="green"))
+                self.console.print(response)
             
             # Обновляем статистику
             self.session_stats["queries"] += 1
